<?php
/*
 Plugin Name: BuddyPress Forums Extras
 Plugin URI: http://wordpress.org/extend/plugins/buddypress-group-forum-extras/
 Description: Additional features for BuddyPress Group Forums (this is a required wrapper)
 Author: rich fuller - etiviti (rich!)
 Author URI: http://buddypress.org/developers/nuprn1/
 License: GNU GENERAL PUBLIC LICENSE 3.0 http://www.gnu.org/licenses/gpl.txt
 Version: 0.1.5
 Text Domain: bp-forums-extras
 Site Wide Only: true
*/

function adminfix_bbpress_init() {
	global $bbdb, $bb_roles, $wp_roles;

	if ( is_object( $bbdb ) && is_object( $bb_roles ) ) {
		return;
	}
	if ( is_object( $bbdb ) ) {
		$bb_roles =& $wp_roles;
		bb_init_roles( $bb_roles );
		return;
	}

	do_action( 'bbpress_init');

}

function bp_forum_extras_setup_globals() {

	//don't care to load on these pages - we don't do anything and plus the bbpress_init causes function redeclaration fatal errors.
	if ( bp_is_register_page() || bp_is_activation_page() || bp_is_user_blogs() )
		return;

	if ( bp_forum_extras_blogs_component() )
		return;

	adminfix_bbpress_init();
	
	add_filter( 'bp_forums_allowed_tags', 'bp_forum_extras_allowed_tags', 1, 1 );
	
	do_action('bp_forum_extras_setup_globals');
	
}
if (defined('WP_ADMIN') && WP_ADMIN) {
	add_action( 'admin_init', 'bp_forum_extras_setup_globals', 500 );
} else {
	add_action( 'bp_init', 'bp_forum_extras_setup_globals', 100 );
}


function bp_forum_extras_forumsdirectory_component() {
	global $bp;

	if ( BP_FORUMS_SLUG == $bp->current_component )
		return true;

	return false;
}

function bp_forum_extras_blogs_component() {
	global $bp;

	//why does is_blog_page return true within wpmu admin?
	if ( bp_core_is_multisite() && !(defined('WP_ADMIN') && WP_ADMIN) && ( $bp->current_component == $bp->blogs->slug || bp_is_blog_page() ) )
		return true;
		
	if ( bp_core_is_multisite() && (basename($_SERVER['PHP_SELF']) == 'wp-signup.php' || basename($_SERVER['PHP_SELF']) == 'register.php'  || basename($_SERVER['PHP_SELF']) == 'wp-register.php') )
		return true;

	return false;
}

//add a few more - 
function bp_forum_extras_allowed_tags( $tags ) {
	
	$new_tags = array('font','strike','center','u','blockquote','cite','pre','hr', 'ul', 'ol', 'li');
	foreach ($new_tags as $tag) {
		$tags[$tag]=array();
	}
	return $tags;
}

function bp_forum_extras_filter_allowedtags( ) {
	global $allowedtags;

	$forums_allowedtags = $allowedtags;
	$forums_allowedtags['span'] = array();
	$forums_allowedtags['span']['class'] = array();
	$forums_allowedtags['div'] = array();
	$forums_allowedtags['div']['class'] = array();
	$forums_allowedtags['div']['id'] = array();
	$forums_allowedtags['a']['class'] = array();
	$forums_allowedtags['br'] = array();
	$forums_allowedtags['p'] = array();
	$forums_allowedtags['code'] = array();
	$forums_allowedtags['blockquote'] = array();
	$forums_allowedtags['img'] = array();
	$forums_allowedtags['img']['src'] = array();
	$forums_allowedtags['img']['alt'] = array();
	$forums_allowedtags['img']['class'] = array();
	$forums_allowedtags['img']['width'] = array();
	$forums_allowedtags['img']['height'] = array();
	$forums_allowedtags['img']['class'] = array();
	$forums_allowedtags['img']['id'] = array();

	return apply_filters( 'bp_forums_allowed_tags', $forums_allowedtags );
}

function _bbbp_forums_encode_bad_empty(&$text, $key, $preg) {
	if (strpos($text, '`') !== 0)
		$text = preg_replace("|&lt;($preg)\s*?/*?&gt;|i", '<$1 />', $text);
}

function _bbbp_forums_encode_bad_normal(&$text, $key, $preg) {
	if (strpos($text, '`') !== 0)
		$text = preg_replace("|&lt;(/?$preg)&gt;|i", '<$1>', $text);
}

function bbbp_forums_encode_bad( $text ) {
	$text = wp_specialchars( $text, ENT_NOQUOTES );

	$text = preg_split('@(`[^`]*`)@m', $text, -1, PREG_SPLIT_NO_EMPTY + PREG_SPLIT_DELIM_CAPTURE);

	$allowed = bp_forum_extras_filter_allowedtags();
	$empty = array( 'br' => true, 'hr' => true, 'input' => true, 'param' => true, 'area' => true, 'col' => true, 'embed' => true );

	foreach ( $allowed as $tag => $args ) {
		$preg = $args ? "$tag(?:\s.*?)?" : $tag;

		if ( isset( $empty[$tag] ) )
			array_walk($text, '_bbbp_forums_encode_bad_empty', $preg);
		else
			array_walk($text, '_bbbp_forums_encode_bad_normal', $preg);
	}

	return join('', $text);
}


function bp_forum_extras_topic_links() {
	do_action('bp_forum_extras_add_topic_links');
}
add_action('bp_forum_extras_topic_links','bp_forum_extras_topic_links');

/**
 * Admin menus action
 */
function bp_forum_extras_add_admin_menu() {
	global $bp;

	if ( !is_site_admin() )
		return false;

	//Add the component's administration tab under the "BuddyPress" menu for site administrators
	require ( dirname( __FILE__ ) . '/bp-forum-extras-admin.php' );

	add_submenu_page( 'bp-general-settings', __( 'Forum Extras', 'bp-forums-extras' ), '<span class="bp-forums-extras-admin-menu-header">' . __( 'Forum Extras', 'bp-forums-extras' ) . '&nbsp;&nbsp;&nbsp;</span>', 'manage_options', 'bp-forums-extras-settings', 'bp_forum_extras_admin' );

	do_action('bp_forum_extras_admin_menu');

}

if ( defined( 'BP_VERSION' ) ) {
	add_action( 'admin_menu', 'bp_forum_extras_init', 20 );
	add_filter('plugin_row_meta', 'bp_forum_extras_add_admin_plugin_link', 10, 2);
} else {
	add_action( 'bp_init', 'bp_forum_extras_init');
}

function bp_forum_extras_init() {
	add_action( 'admin_menu', 'bp_forum_extras_add_admin_menu', 25 );
	add_filter('plugin_row_meta', 'bp_forum_extras_add_admin_plugin_link', 10, 2);
}




//settings link on plugin page (i like it so tphtphphphphph)
function bp_forum_extras_add_admin_plugin_link($links, $file) {

	if ( !is_site_admin() )
		return false;

	$base = plugin_basename(__FILE__);
	if ($file == $base) {
		$links[] = '<a href="admin.php?page=bp-forums-extras-settings">' . __('Settings','bp-forums-extras') . '</a>';
	}
	return $links;
}

?>
